==> humhub-1.8.1.tar.gz: humhub-1.8.1/protected/humhub/modules/admin/messages/lv/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Informācija</strong>',
  '<strong>Profile</strong> Permissions' => '',
  '<strong>Settings</strong> and Configuration' => '<strong>Uzstādījumi</strong> un konfigurācija',
  '<strong>User</strong> administration' => '<strong>Lietotāju</strong> administrēšana',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '',
  'Accept user: <strong>{displayName}</strong> ' => '',
  'Account' => '',
  'Account Request for \'{displayName}\' has been approved.' => 'Konta \'{displayName}\' pieprasījums ir apstiprināts.',
  'Account Request for \'{displayName}\' has been declined.' => 'Konta \'{displayName}\' pieprasījums ir noraidīts.',
  'Actions' => '',
  'Active users' => '',
  'Add Groups...' => 'Pievienot grupas...',
  'Add a separate page for the group to the directory.' => '',
  'Add new category' => '',
  'Add new field' => '',
  'Add new group' => 'Pievienot jaunu grupu',
  'Add new members...' => '',
  'Add new user' => '',
  'Administrator group could not be deleted!' => '',
  'All open registration invitations were successfully deleted.' => '',
  'All the personal data of this user will be irrevocably deleted.' => '',
  'Allow' => 'Atļaut',
  'Allow users to set individual permissions for their own profile?' => '',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Atļaut limitētu piekļuvi neautentificētiem lietotājiem (viesiem)',
  'Applied to new or existing users without any other group membership.' => '',
  'Are you really sure that you want to disable this user?' => '',
  'Are you really sure that you want to enable this user?' => '',
  'Are you really sure that you want to impersonate this user?' => '',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => '',
  'Are you sure that you want to delete following user?' => '',
  'Cancel' => 'Atcelt',
  'Click here to review' => '',
  'Confirm user deletion' => '',
  'Could not load category.' => 'Nevar ielādēt kategoriju.',
  'Create new group' => '',
  'Create new profile category' => '',
  'Create new profile field' => '',
  'Deactivate' => '',
  'Deactivate individual profile permissions?' => '',
  'Decline & delete user: <strong>{displayName}</strong>' => '',
  'Default' => 'Noklusēts',
  'Default Profile Permissions' => '',
  'Default content of the registration approval email' => '',
  'Default content of the registration denial email' => '',
  'Default groups can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Noklusētā lietotāja dīkstāve, auto-iziešana (sekundēs, nav obligāts)',
  'Default user profile visibility' => 'Noklētā lietotāja profila redzamība',
  'Delete' => 'Dzēst',
  'Delete All' => '',
  'Delete all contributions of this user' => '',
  'Delete invitation' => '',
  'Delete invitation?' => '',
  'Delete spaces which are owned by this user' => '',
  'Deleted invitation' => '',
  'Deleted users' => '',
  'Disable' => '',
  'Disabled' => 'Atslēgts',
  'Disabled users' => '',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => '',
  'Edit category' => '',
  'Edit profile category' => '',
  'Edit profile field' => '',
  'Edit user: {name}' => '',
  'Enable' => '',
  'Enable individual profile permissions' => '',
  'Enabled' => 'Ieslēgts',
  'Group Manager' => '',
  'Group not found!' => 'Grupa nav atrasta!',
  'Group user not found!' => 'Grupas lietotājs nav atrasts!',
  'Groups' => 'Grupas',
  'Hello {displayName},<br><br>
Your account has been activated.<br><br>
Click here to login:<br>
{loginLink}<br><br>

Kind Regards<br>
{AdminName}<br><br>' => '',
  'Hello {displayName},<br><br>
Your account request has been declined.<br><br>

Kind Regards<br>
{AdminName} <br><br> ' => '',
  'Here you can create or edit profile categories and fields.' => '',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => '',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => '',
  'Impersonate' => '',
  'Include captcha in registration form' => '',
  'Invite not found!' => '',
  'Last login' => '',
  'List pending registrations' => '',
  'Make the group selectable at registration.' => '',
  'Manage group: {groupName}' => 'Pārvaldīt grupu: {groupName}',
  'Manage groups' => '',
  'Manage profile attributes' => '',
  'Member since' => '',
  'Members' => 'Dalībnieki',
  'Members can invite external users by email' => 'Lietotāji var uzaicināt ārējos lietotājus ar e-pastu',
  'Message' => 'Ziņa',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => '',
  'New approval requests' => '',
  'New users can register' => 'Anonīmi lietotāji var reģistrēties',
  'No' => '',
  'No value found!' => 'Vērtība nav atrasta!',
  'One or more user needs your approval as group admin.' => '',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => '',
  'Overview' => 'Pārskats',
  'Password' => 'Parole',
  'Pending approvals' => 'Gaida apstiprinājumu',
  'Pending user approvals' => '',
  'Permanently delete' => '',
  'Permissions' => 'Atļaujas',
  'Profile Permissions' => '',
  'Profiles' => 'Profili',
  'Remove from group' => '',
  'Require group admin approval after registration' => 'Pieprasīt grupas administrātora apstiprināju pēc reģistrācijas',
  'Resend invitation email' => '',
  'Save' => 'Saglabāt',
  'Search by name, email or id.' => '',
  'Select Groups' => 'Izvēlies grupas',
  'Send & save' => '',
  'Send invitation email' => '',
  'Send invitation email again?' => '',
  'Send invite' => 'Sūtīt ielūgumu',
  'Send notifications to users when added to or removed from the group.' => '',
  'Settings' => 'Uzstādījumi',
  'Show group selection at registration' => '',
  'Subject' => 'Tēma',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => '',
  'The following list contains all pending sign-ups and invites.' => '',
  'The following list contains all registered users awaiting an approval.' => '',
  'The selected invitations have been successfully deleted!' => '',
  'The user is the owner of these spaces:' => '',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => '',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => '',
  'This user owns no spaces.' => '',
  'Unapproved' => 'Neapstiprināts',
  'User deletion process queued.' => '',
  'User is already a member of this group.' => 'Lietotājs jau šīs grupas lietotājs.',
  'User not found!' => 'Lietotājs nav atrasts!',
  'Users' => 'Lietotāji',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => '',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => '',
  'View profile' => '',
  'Visible for members only' => '',
  'Visible for members+guests' => '',
  'Yes' => '',
  'You can only delete empty categories!' => 'Tu vari dzēst tikai tukšas kategorijas!',
  'You cannot delete yourself!' => 'Tu nevari izdzēst sevi!',
  'never' => 'nekad',
);

==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/admin/messages/lv/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Informācija</strong>',
  '<strong>Profile</strong> Permissions' => '',
  '<strong>Settings</strong> and Configuration' => '<strong>Uzstādījumi</strong> un konfigurācija',
  '<strong>User</strong> administration' => '<strong>Lietotāju</strong> administrēšana',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '',
  'Accept user: <strong>{displayName}</strong> ' => '',
  'Account' => '',
  'Account Request for \'{displayName}\' has been approved.' => 'Konta \'{displayName}\' pieprasījums ir apstiprināts.',
  'Account Request for \'{displayName}\' has been declined.' => 'Konta \'{displayName}\' pieprasījums ir noraidīts.',
  'Actions' => '',
  'Active users' => '',
  'Add Groups...' => 'Pievienot grupas...',
  'Add new category' => '',
  'Add new field' => '',
  'Add new group' => 'Pievienot jaunu grupu',
  'Add new members...' => '',
  'Add new user' => '',
  'Administrator group could not be deleted!' => '',
  'All open registration invitations were successfully deleted.' => '',
  'All the personal data of this user will be irrevocably deleted.' => '',
  'Allow' => 'Atļaut',
  'Allow users to block each other' => '',
  'Allow users to set individual permissions for their own profile?' => '',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Atļaut limitētu piekļuvi neautentificētiem lietotājiem (viesiem)',
  'Applied to new or existing users without any other group membership.' => '',
  'Are you really sure that you want to disable this user?' => '',
  'Are you really sure that you want to enable this user?' => '',
  'Are you really sure that you want to impersonate this user?' => '',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => '',
  'Are you sure that you want to delete following user?' => '',
  'Cancel' => 'Atcelt',
  'Click here to review' => '',
  'Confirm user deletion' => '',
  'Could not load category.' => 'Nevar ielādēt kategoriju.',
  'Create new group' => '',
  'Create new profile category' => '',
  'Create new profile field' => '',
  'Deactivate' => '',
  'Deactivate individual profile permissions?' => '',
  'Decline & delete user: <strong>{displayName}</strong>' => '',
  'Default' => 'Noklusēts',
  'Default Profile Permissions' => '',
  'Default Sorting' => '',
  'Default content of the registration approval email' => '',
  'Default content of the registration denial email' => '',
  'Default group can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Noklusētā lietotāja dīkstāve, auto-iziešana (sekundēs, nav obligāts)',
  'Default user profile visibility' => 'Noklētā lietotāja profila redzamība',
  'Delete' => 'Dzēst',
  'Delete All' => '',
  'Delete all contributions of this user' => '',
  'Delete invitation' => '',
  'Delete invitation?' => '',
  'Delete spaces which are owned by this user' => '',
  'Deleted invitation' => '',
  'Deleted users' => '',
  'Disable' => '',
  'Disabled' => 'Atslēgts',
  'Disabled users' => '',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => '',
  'Edit category' => '',
  'Edit profile category' => '',
  'Edit profile field' => '',
  'Edit user: {name}' => '',
  'Enable' => '',
  'Enable individual profile permissions' => '',
  'Enabled' => 'Ieslēgts',
  'First name' => '',
  'Group Manager' => '',
  'Group not found!' => 'Grupa nav atrasta!',
  'Group user not found!' => 'Grupas lietotājs nav atrasts!',
  'Groups' => 'Grupas',
  'Hello {displayName},

Your account has been activated.

Click here to login:
{loginUrl}

Kind Regards
{AdminName}

' => '',
  'Hello {displayName},

Your account request has been declined.

Kind Regards
{AdminName}

' => '',
  'Here you can create or edit profile categories and fields.' => '',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => '',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => '',
  'Impersonate' => '',
  'Include captcha in registration form' => '',
  'Information 1' => '',
  'Information 2' => '',
  'Information 3' => '',
  'Invite not found!' => '',
  'Last login' => '',
  'Last name' => '',
  'List pending registrations' => '',
  'Make the group selectable at registration.' => '',
  'Manage group: {groupName}' => 'Pārvaldīt grupu: {groupName}',
  'Manage groups' => '',
  'Manage profile attributes' => '',
  'Member since' => '',
  'Members' => 'Dalībnieki',
  'Members can invite external users by email' => 'Lietotāji var uzaicināt ārējos lietotājus ar e-pastu',
  'Message' => 'Ziņa',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => '',
  'New approval requests' => '',
  'New users can register' => 'Anonīmi lietotāji var reģistrēties',
  'No' => '',
  'No value found!' => 'Vērtība nav atrasta!',
  'None' => '',
  'Not visible' => '',
  'One or more user needs your approval as group admin.' => '',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => '',
  'Overview' => 'Pārskats',
  'Password' => 'Parole',
  'Pending approvals' => 'Gaida apstiprinājumu',
  'Pending user approvals' => '',
  'People' => '',
  'Permanently delete' => '',
  'Permissions' => 'Atļaujas',
  'Prioritised User Group' => '',
  'Profile Permissions' => '',
  'Profiles' => 'Profili',
  'Protected' => '',
  'Protected group can not be deleted!' => '',
  'Remove from group' => '',
  'Require group admin approval after registration' => 'Pieprasīt grupas administrātora apstiprināju pēc reģistrācijas',
  'Resend invitation email' => '',
  'Save' => 'Saglabāt',
  'Search by name, email or id.' => '',
  'Select Groups' => 'Izvēlies grupas',
  'Select a prioritised group whose members are displayed before all others when the sorting option \'Default\' is selected. The users within the group and the users outside the group are additionally sorted by their last login.' => '',
  'Select which user information should be displayed in the \'People\' overview. You can select any profile fields, even those you have created individually. ' => '',
  'Send & decline' => 'Nosūtīt un noraidīt',
  'Send & save' => '',
  'Send invitation email' => '',
  'Send invitation email again?' => '',
  'Send invite' => 'Sūtīt ielūgumu',
  'Send notifications to users when added to or removed from the group.' => '',
  'Settings' => 'Uzstādījumi',
  'Show group selection at registration' => '',
  'Subject' => 'Tēma',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => '',
  'The following list contains all pending sign-ups and invites.' => '',
  'The following list contains all registered users awaiting an approval.' => '',
  'The selected invitations have been successfully deleted!' => '',
  'The user is the owner of these spaces:' => '',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => '',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => '',
  'This user owns no spaces.' => '',
  'Unapproved' => 'Neapstiprināts',
  'User deletion process queued.' => '',
  'User is already a member of this group.' => 'Lietotājs jau šīs grupas lietotājs.',
  'User not found!' => 'Lietotājs nav atrasts!',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => '',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => '',
  'View profile' => '',
  'Visible for members only' => '',
  'Visible for members+guests' => '',
  'Will be used as a filter in \'People\'.' => '',
  'Yes' => '',
  'You can only delete empty categories!' => 'Tu vari dzēst tikai tukšas kategorijas!',
  'You cannot delete yourself!' => 'Tu nevari izdzēst sevi!',
  'never' => 'nekad',
);
